@@ -138,7 +138,7 @@ class Cell(StyleableObject):
     def coordinate(self):
         """This cell's coordinate (ex. 'A5')"""
         col = get_column_letter(self.column)
-        return "%s%d" % (col, self.row)
+        return f"{col}{self.row}"
 
 
     @property
