@@ -1,4 +1,3 @@
-from __future__ import absolute_import
 # Copyright (c) 2010-2019 openpyxl
 
 """
@@ -43,46 +42,22 @@ if LXML is True:
         fromstring = partial(fromstring, parser=safe_parser)
 
 else:
-    try:
-        from xml.etree.cElementTree import (
-        ElementTree,
-        Element,
-        SubElement,
-        QName,
-        register_namespace
+    from xml.etree.ElementTree import (
+    ElementTree,
+    Element,
+    SubElement,
+    fromstring,
+    tostring,
+    iterparse,
+    QName,
+    register_namespace
+    )
+    if DEFUSEDXML is True:
+        from defusedxml.cElementTree import (
+        fromstring,
+        tostring,
+        iterparse,
         )
-        if DEFUSEDXML is True:
-            from defusedxml.cElementTree import (
-            fromstring,
-            tostring,
-            iterparse,
-            )
-        else:
-            from xml.etree.cElementTree import (
-            fromstring,
-            tostring,
-            iterparse
-            )
-    except ImportError:
-        from xml.etree.ElementTree import (
-        ElementTree,
-        Element,
-        SubElement,
-        QName,
-        register_namespace
-        )
-        if DEFUSEDXML is True:
-            from defusedxml.ElementTree import (
-            fromstring,
-            tostring,
-            iterparse,
-            )
-        else:
-            from xml.etree.ElementTree import (
-            fromstring,
-            tostring,
-            iterparse,
-            )
     from et_xmlfile import xmlfile
 
 
@@ -96,7 +71,8 @@ from openpyxl.xml.constants import (
     VTYPES_NS,
     COREPROPS_NS,
     DCTERMS_NS,
-    DCTERMS_PREFIX
+    DCTERMS_PREFIX,
+    XML_NS
 )
 
 register_namespace(DCTERMS_PREFIX, DCTERMS_NS)
@@ -109,6 +85,7 @@ register_namespace('r', REL_NS)
 register_namespace('vt', VTYPES_NS)
 register_namespace('xdr', SHEET_DRAWING_NS)
 register_namespace('cdr', CHART_DRAWING_NS)
+register_namespace('xml', XML_NS)
 
 
 tostring = partial(tostring, encoding="utf-8")
@@ -120,3 +97,8 @@ def localname(node):
         return "comment"
     m = NS_REGEX.match(node.tag)
     return m.group('localname')
+
+
+def whitespace(node):
+    if node.text != node.text.strip():
+        node.set("{%s}space" % XML_NS, "preserve")
